@@ -1,7 +1,5 @@
-from click import echo
-
 from wack.builders import PackageBuilt
 from wack.builders import PipInstallable
-from wack.core import command
+from wack.core import command, echo
 
 __all__ = ["PackageBuilt", "PipInstallable", "command", "echo"]
